==> haskell-dav-1.3.1-158-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-4UYjJzTvNPpItkrxF2O4AN
key: DAV-1.3.1-4UYjJzTvNPpItkrxF2O4AN
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: 6adaf6d629097ee6721eaf3cda610056
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/DAV-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-4UYjJzTvNPpItkrxF2O4AN
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI containers-0.5.10.2
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn transformers-0.5.2.0
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG
    xml-hamlet-0.4.1-6KwjlOh9kO281XKrJ5dhAs
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J=bfd2559218a81acc5cfe715436ea1e49
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             xml-conduit-1.6.0-BWoyzWzm2lWEOl7Dzk57oG=f75d67ad0439bcc94bf75dda8c0736b1
             xml-hamlet-0.4.1-6KwjlOh9kO281XKrJ5dhAs=e9f164ed74716124b367ee409b9d5559
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.1-160-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-GvB5ZTCUIewHJyq7cE96bB
key: DAV-1.3.1-GvB5ZTCUIewHJyq7cE96bB
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: 958c61a7fc220e1edf3b51ae3d0f3128
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/DAV-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-GvB5ZTCUIewHJyq7cE96bB
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI containers-0.5.10.2
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn transformers-0.5.2.0
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm
    xml-hamlet-0.4.1.1-7xfNBeGMskB2KtKlxRg0H3
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J=bfd2559218a81acc5cfe715436ea1e49
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm=d68311a22f18e80895f9913dd3408b62
             xml-hamlet-0.4.1.1-7xfNBeGMskB2KtKlxRg0H3=dff55a377bfe3d75d53028cfb2a20bed
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
